##  Introduction
Joule is a generative AI assistant in SAP’s ecosystem that understands user requests through conversational interactions, retrieves relevant information, and assists you in completing your tasks.
Joule helps you access resources like fact sheets, reports, or diagrams without the need for manual navigation. While such actions are available in SAP LeanIX, general tasks, like finding information can be done across other areas of the SAP ecosystem where Joule is accessible.
